@@ -17,7 +17,7 @@ mkdir -p ${ORIG_TARBALL_DIR}
 tar --directory=${ORIG_TARBALL_DIR} --strip 1 -xzf ${REAL_TARBALL} || exit 1 
 rm -f ${ORIG_TARBALL} ${REAL_TARBALL}
 ant -f ${ORIG_TARBALL_DIR}/build.xml clean
-rm -rf ${ORIG_TARBALL_DIR}/jars/*.* ${ORIG_TARBALL_DIR}/plugin-jars/*.* ${ORIG_TARBALL_DIR}/tools/*.jar
+find ${ORIG_TARBALL_DIR}/ -name "*.jar" -o -name "*.exe" -o -name "*.dll" -o -name "jcfl-*.tar.gz" | xargs rm -f
 GZIP=-9 tar --remove-files --directory ${WORKING_DIR} -czf ${ORIG_TARBALL_DFSG} ${ORIG_TARBALL_DIR_STRIP} || exit 1
 
 exit 0
